@@ -10,7 +10,6 @@ def get_gey_values(row, keys):
 def format_results_create_delete(row  ,operation, keys) -> dict:
     """ Process create and delete entry"""
     key_values = get_gey_values(row, keys)
-    a=0
     d = {
         "operation"         : operation,
         "object_keys"       : keys,
@@ -27,9 +26,9 @@ def format_results_modify( row, keys , attribute_changed ,  old_value,  new_valu
         "operation"         : "modify",
         "object_keys"       : keys,
         "object_values"     : key_values,
+        "object_json"       : row.to_dict(),
         "attribute_changed" : attribute_changed,
         "old_value"         : old_value,
-        "new_value"         : new_value,
-        "object_json"       : row.to_dict(),
+        "new_value"         : new_value
     }
     return d
